==> live-player-support-tracker-1.0.7-sources.jar: com/mm/live/player/catchup/CatchUpPlayInfo.java <==
package com.mm.live.player.catchup;

public class CatchUpPlayInfo {
    private String mIconUrl;
    private String mChannelId;
    private String mChannelKey;
    private int mChannelNum;
    private String mChannelName;
    private String mCurrentProgramName;
    private String mNextProgramName;
    private long mBeginTime;
    private long mEndTime;
    private String mCpsContent;

    private String aid = "";
    private String psn = "";
    private String cid = "";
    private String tracker = "";
    private String defaultPrt = "";
    private String epgId = "";
    private String startTime = "";
    private String during = "";
    private String soluba = "";
    private String soluty = "";
    private String protocol = "";
    private String drmLink = "";
    private String eproxy = "";
    private String token = "";
    private String asn = "";
    private String vid = "";
    private String chn = "";
    private String appVer = "";
    private int userType = 0;
    private String prefix = "";
    private String otherParas = "";

    private long delay; //时移功能使用，当前时间往前播放多长时间
    private String moreParams; //startVodChannel接口调用更多参数

    public String getIconUrl() {
        return mIconUrl;
    }

    public void setIconUrl(String iconUrl) {
        mIconUrl = iconUrl;
    }

    public String getChannelId() {
        return mChannelId;
    }

    public void setChannelId(String channelId) {
        mChannelId = channelId;
    }

    public String getChannelKey() {
        return this.mChannelKey;
    }

    public void setChannelKey(String channelKey) {
        this.mChannelKey = channelKey;
    }

    public int getChannelNum() {
        return mChannelNum;
    }

    public void setChannelNum(int channelNum) {
        mChannelNum = channelNum;
    }

    public String getChannelName() {
        return mChannelName;
    }

    public void setChannelName(String channelName) {
        mChannelName = channelName;
    }

    public String getCurrentProgramName() {
        return mCurrentProgramName;
    }

    public void setCurrentProgramName(String currentProgramName) {
        mCurrentProgramName = currentProgramName;
    }

    public String getNextProgramName() {
        return mNextProgramName;
    }

    public void setNextProgramName(String nextProgramName) {
        mNextProgramName = nextProgramName;
    }

    public long getBeginTime() {
        return mBeginTime;
    }

    public void setBeginTime(long beginTime) {
        mBeginTime = beginTime;
    }

    public long getEndTime() {
        return mEndTime;
    }

    public void setEndTime(long endTime) {
        mEndTime = endTime;
    }

    public String getCpsContent() {
        return mCpsContent;
    }

    public void setCpsContent(String cpsContent) {
        mCpsContent = cpsContent;
    }

    public String getAid() {
        return aid;
    }

    public void setAid(String aid) {
        this.aid = aid;
    }

    public String getPsn() {
        return psn;
    }

    public void setPsn(String psn) {
        this.psn = psn;
    }

    public String getCid() {
        return cid;
    }

    public void setCid(String cid) {
        this.cid = cid;
    }

    public String getTracker() {
        return tracker;
    }

    public void setTracker(String tracker) {
        this.tracker = tracker;
    }

    public String getDefaultPrt() {
        return defaultPrt;
    }

    public void setDefaultPrt(String defaultPrt) {
        this.defaultPrt = defaultPrt;
    }

    public String getEpgId() {
        return epgId;
    }

    public void setEpgId(String epgId) {
        this.epgId = epgId;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getDuring() {
        return during;
    }

    public void setDuring(String during) {
        this.during = during;
    }

    public String getSoluba() {
        return soluba;
    }

    public void setSoluba(String soluba) {
        this.soluba = soluba;
    }

    public String getSoluty() {
        return soluty;
    }

    public void setSoluty(String soluty) {
        this.soluty = soluty;
    }

    public String getProtocol() {
        return protocol;
    }

    public void setProtocol(String protocol) {
        this.protocol = protocol;
    }

    public String getDrmLink() {
        return drmLink;
    }

    public void setDrmLink(String drmLink) {
        this.drmLink = drmLink;
    }

    public String getEproxy() {
        return eproxy;
    }

    public void setEproxy(String eproxy) {
        this.eproxy = eproxy;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public String getAsn() {
        return asn;
    }

    public void setAsn(String asn) {
        this.asn = asn;
    }

    public String getVid() {
        return vid;
    }

    public void setVid(String vid) {
        this.vid = vid;
    }

    public String getChn() {
        return chn;
    }

    public void setChn(String chn) {
        this.chn = chn;
    }

    public String getAppVer() {
        return appVer;
    }

    public void setAppVer(String appVer) {
        this.appVer = appVer;
    }

    public int getUserType() {
        return userType;
    }

    public void setUserType(int userType) {
        this.userType = userType;
    }

    public String getPrefix() {
        return prefix;
    }

    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }

    public String getOtherParas() {
        return otherParas;
    }

    public void setOtherParas(String otherParas) {
        this.otherParas = otherParas;
    }

    public long getDelay() {
        return delay;
    }

    public void setDelay(long delay) {
        this.delay = delay;
    }

    public String getMoreParams() {
        return moreParams;
    }

    public void setMoreParams(String moreParams) {
        this.moreParams = moreParams;
    }
}

==> live-player-support-tracker-1.0.9-20230615.061302-1-sources.jar: com/mm/live/player/catchup/CatchUpPlayInfo.java <==
package com.mm.live.player.catchup;

public class CatchUpPlayInfo {
    private String epgId = "";
    private String mChannelId;
    private String streamId = "";

    private String key;

    private String mIconUrl;
    private int mChannelNum;
    private String mChannelName;
    private String mCurrentProgramName;
    private String mNextProgramName;
    private long mBeginTime;
    private long mEndTime;
    private String mCpsContent;

    private String aid = "";
    private String psn = "";
    private String cid = "";
    private String tracker = "";
    private String defaultPrt = "";
    private String startTime = "";
    private String during = "";
    private String soluba = "";
    private String soluty = "";
    private String protocol = "";
    private String drmLink = "";
    private String eproxy = "";
    private String token = "";
    private String asn = "";
    private String vid = "";
    private String chn = "";
    private String appVer = "";
    private int userType = 0;
    private String prefix = "";
    private String otherParas = "";

    private long delay; //时移功能使用，当前时间往前播放多长时间
    private String moreParams; //startVodChannel接口调用更多参数

    public String getIconUrl() {
        return mIconUrl;
    }

    public void setIconUrl(String iconUrl) {
        mIconUrl = iconUrl;
    }

    public String getChannelId() {
        return this.mChannelId;
    }

    public void setChannelId(String channelKey) {
        this.mChannelId = channelKey;
    }

    public int getChannelNum() {
        return mChannelNum;
    }

    public void setChannelNum(int channelNum) {
        mChannelNum = channelNum;
    }

    public String getChannelName() {
        return mChannelName;
    }

    public void setChannelName(String channelName) {
        mChannelName = channelName;
    }

    public String getCurrentProgramName() {
        return mCurrentProgramName;
    }

    public void setCurrentProgramName(String currentProgramName) {
        mCurrentProgramName = currentProgramName;
    }

    public String getNextProgramName() {
        return mNextProgramName;
    }

    public void setNextProgramName(String nextProgramName) {
        mNextProgramName = nextProgramName;
    }

    public long getBeginTime() {
        return mBeginTime;
    }

    public void setBeginTime(long beginTime) {
        mBeginTime = beginTime;
    }

    public long getEndTime() {
        return mEndTime;
    }

    public void setEndTime(long endTime) {
        mEndTime = endTime;
    }

    public String getCpsContent() {
        return mCpsContent;
    }

    public void setCpsContent(String cpsContent) {
        mCpsContent = cpsContent;
    }

    public String getAid() {
        return aid;
    }

    public void setAid(String aid) {
        this.aid = aid;
    }

    public String getPsn() {
        return psn;
    }

    public void setPsn(String psn) {
        this.psn = psn;
    }

    public String getCid() {
        return cid;
    }

    public void setCid(String cid) {
        this.cid = cid;
    }

    public String getTracker() {
        return tracker;
    }

    public void setTracker(String tracker) {
        this.tracker = tracker;
    }

    public String getDefaultPrt() {
        return defaultPrt;
    }

    public void setDefaultPrt(String defaultPrt) {
        this.defaultPrt = defaultPrt;
    }

    public String getEpgId() {
        return epgId;
    }

    public void setEpgId(String epgId) {
        this.epgId = epgId;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getDuring() {
        return during;
    }

    public void setDuring(String during) {
        this.during = during;
    }

    public String getSoluba() {
        return soluba;
    }

    public void setSoluba(String soluba) {
        this.soluba = soluba;
    }

    public String getSoluty() {
        return soluty;
    }

    public void setSoluty(String soluty) {
        this.soluty = soluty;
    }

    public String getProtocol() {
        return protocol;
    }

    public void setProtocol(String protocol) {
        this.protocol = protocol;
    }

    public String getDrmLink() {
        return drmLink;
    }

    public void setDrmLink(String drmLink) {
        this.drmLink = drmLink;
    }

    public String getEproxy() {
        return eproxy;
    }

    public void setEproxy(String eproxy) {
        this.eproxy = eproxy;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public String getAsn() {
        return asn;
    }

    public void setAsn(String asn) {
        this.asn = asn;
    }

    public String getVid() {
        return vid;
    }

    public void setVid(String vid) {
        this.vid = vid;
    }

    public String getChn() {
        return chn;
    }

    public void setChn(String chn) {
        this.chn = chn;
    }

    public String getAppVer() {
        return appVer;
    }

    public void setAppVer(String appVer) {
        this.appVer = appVer;
    }

    public int getUserType() {
        return userType;
    }

    public void setUserType(int userType) {
        this.userType = userType;
    }

    public String getPrefix() {
        return prefix;
    }

    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }

    public String getOtherParas() {
        return otherParas;
    }

    public void setOtherParas(String otherParas) {
        this.otherParas = otherParas;
    }

    public long getDelay() {
        return delay;
    }

    public void setDelay(long delay) {
        this.delay = delay;
    }

    public String getMoreParams() {
        return moreParams;
    }

    public void setMoreParams(String moreParams) {
        this.moreParams = moreParams;
    }

    public String getStreamId() {
        return streamId;
    }

    public void setStreamId(String streamId) {
        this.streamId = streamId;
    }

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }
}
